@@ -15,16 +15,16 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02111-1307, USA.
  *
- * $Id: battstat-hal.h,v 1.1 2005/07/04 07:16:22 ryanl Exp $
+ * $Id: battstat-hal.h,v 1.2 2006/09/21 23:07:58 ryanl Exp $
  */
 
 #ifndef _battstat_hal_h_
 #define _battstat_hal_h_
 
-char *battstat_hal_initialise( void );
-void battstat_hal_cleanup( void );
+char *battstat_hal_initialise (void (*) (void));
+void battstat_hal_cleanup (void);
 
 #include "battstat.h"
-void battstat_hal_get_battery_info( BatteryStatus *status );
+void battstat_hal_get_battery_info (BatteryStatus *status);
 
 #endif /* _battstat_hal_h_ */
