@@ -1,4 +1,4 @@
-/* $Id: gweather-pref.c,v 1.101 2006/05/29 23:04:55 philipl Exp $ */
+/* $Id: gweather-pref.c,v 1.103 2006/10/02 14:08:55 davyd Exp $ */
 
 /*
  *  Papadimitriou Spiros <spapadim+@cs.cmu.edu>
@@ -372,7 +372,9 @@ static void temp_combo_changed_cb (GtkComboBox *combo, GWeatherPref *pref)
 
     gtk_label_set_text(GTK_LABEL(gw_applet->label), 
                        weather_info_get_temp_summary(gw_applet->gweather_info));
-    gweather_dialog_update (GWEATHER_DIALOG (gw_applet->details_dialog));
+
+    if (gw_applet->details_dialog)
+        gweather_dialog_update (GWEATHER_DIALOG (gw_applet->details_dialog));
 }
 
 static void speed_combo_changed_cb (GtkComboBox *combo, GWeatherPref *pref)
@@ -399,7 +401,8 @@ static void speed_combo_changed_cb (GtkComboBox *combo, GWeatherPref *pref)
                               gweather_prefs_speed_enum_to_string (new_unit),
                                   NULL);
 
-    gweather_dialog_update (GWEATHER_DIALOG (gw_applet->details_dialog));
+    if (gw_applet->details_dialog)
+        gweather_dialog_update (GWEATHER_DIALOG (gw_applet->details_dialog));
 }
 
 static void pres_combo_changed_cb (GtkComboBox *combo, GWeatherPref *pref)
@@ -426,7 +429,8 @@ static void pres_combo_changed_cb (GtkComboBox *combo, GWeatherPref *pref)
                               gweather_prefs_pressure_enum_to_string (new_unit),
                                   NULL);
 
-    gweather_dialog_update (GWEATHER_DIALOG (gw_applet->details_dialog));
+    if (gw_applet->details_dialog)
+        gweather_dialog_update (GWEATHER_DIALOG (gw_applet->details_dialog));
 }
 
 static void dist_combo_changed_cb (GtkComboBox *combo, GWeatherPref *pref)
@@ -453,7 +457,8 @@ static void dist_combo_changed_cb (GtkComboBox *combo, GWeatherPref *pref)
                               gweather_prefs_distance_enum_to_string (new_unit),
                                   NULL);
 
-    gweather_dialog_update (GWEATHER_DIALOG (gw_applet->details_dialog));
+    if (gw_applet->details_dialog)
+        gweather_dialog_update (GWEATHER_DIALOG (gw_applet->details_dialog));
 }
 
 static void
@@ -578,6 +583,10 @@ find_location (GtkTreeModel *model, GtkTreeIter *iter, const gchar *location, gb
 
 	len = strlen (location);
 
+	if (len <= 0) {
+		return FALSE;
+	}
+	
 	do {
 		
 		gtk_tree_model_get (model, iter, GWEATHER_XML_COL_LOC, &aux_loc, -1);
@@ -1084,6 +1093,7 @@ gweather_pref_create (GWeatherPref *pref)
 		    pref->priv->find_entry);
     
     pref->priv->find_next_btn = gtk_button_new_with_label (_("Find _Next"));
+    gtk_widget_set_sensitive (pref->priv->find_next_btn, FALSE);
     
     image = gtk_image_new_from_stock (GTK_STOCK_FIND, GTK_ICON_SIZE_BUTTON); 
     gtk_button_set_image (GTK_BUTTON (pref->priv->find_next_btn), image);
