@@ -212,9 +212,10 @@ gnome_kbd_indicator_prepare_drawing (GnomeKbdIndicator * gki, int group)
 {
 	gpointer pimage;
 	GdkPixbuf *image;
+	GtkWidget *ebox;
 
 	pimage = g_slist_nth_data (globals.applet_cfg.images, group);
-	GtkWidget *ebox = gtk_event_box_new ();
+	ebox = gtk_event_box_new ();
 	if (globals.applet_cfg.show_flags) {
 		GtkWidget *flag;
 		if (pimage == NULL)
@@ -233,7 +234,13 @@ gnome_kbd_indicator_prepare_drawing (GnomeKbdIndicator * gki, int group)
 		char *layout_name = NULL;
 		XklConfigItem cfg_item;
 		GtkWidget *align, *label;
+		/**
+		 * Map "short desciption" -> 
+		 * number of layouts in the configuration 
+		 * having this short description
+		 */
 		static GHashTable *short_descrs = NULL;
+
 		if (group == 0)
 			short_descrs =
 			    g_hash_table_new_full (g_str_hash, g_str_equal,
@@ -241,7 +248,6 @@ gnome_kbd_indicator_prepare_drawing (GnomeKbdIndicator * gki, int group)
 
 		if (xkl_engine_get_features (globals.engine) &
 		    XKLF_MULTIPLE_LAYOUTS_SUPPORTED) {
-			char *short_group_name;
 			char *full_layout_name =
 			    (char *) g_slist_nth_data (globals.kbd_cfg.
 						       layouts,
@@ -257,11 +263,14 @@ gnome_kbd_indicator_prepare_drawing (GnomeKbdIndicator * gki, int group)
 				    sizeof (cfg_item.name), "%s",
 				    layout_name);
 
-			short_group_name =
-			    globals.short_group_names[group];
-			if (short_group_name != NULL
-			    && *short_group_name != '\0') {
-				layout_name = g_strdup (short_group_name);
+			if (globals.short_group_names != NULL) {
+				char *short_group_name =
+				    globals.short_group_names[group];
+				if (short_group_name != NULL
+				    && *short_group_name != '\0') {
+					layout_name =
+					    g_strdup (short_group_name);
+				}
 			}
 		} else
 			layout_name =
@@ -270,18 +279,22 @@ gnome_kbd_indicator_prepare_drawing (GnomeKbdIndicator * gki, int group)
 		if (layout_name == NULL)
 			layout_name = g_strdup ("?");
 
+		/* Process layouts with repeating description */
 		ppln = &prev_layout_name;
 		if (g_hash_table_lookup_extended
 		    (short_descrs, layout_name,
 		     (gpointer *) ppln, &pcounter)) {
 			/* "next" same description */
-			char *appendix = NULL;
+			gchar appendix[10] = "";
+			gint utf8length;
+			gunichar cidx;
 			counter = GPOINTER_TO_INT (pcounter);
-			appendix = g_strnfill (counter, '*');
+			/* Unicode subscript 2, 3, 4 */
+			cidx = 0x2081 + counter;
+			utf8length = g_unichar_to_utf8 (cidx, appendix);
+			appendix[utf8length] = '\0';
 			lbl_title =
 			    g_strconcat (layout_name, appendix, NULL);
-			g_free (appendix);
-			/* layout_name is g_freed inside g_hash_table_insert function */
 		} else {
 			/* "first" time this description */
 			lbl_title = g_strdup (layout_name);
@@ -403,8 +416,8 @@ gnome_kbd_indicator_load_group_names (void)
 		if (xkl_engine_get_features (globals.engine) &
 		    XKLF_MULTIPLE_LAYOUTS_SUPPORTED) {
 			GSList *lst = globals.kbd_cfg.layouts;
-			for (i = 0; lst; lst = lst->next) {
-				globals.full_group_names[i++] =
+			for (i = 0; lst; lst = lst->next, i++) {
+				globals.full_group_names[i] =
 				    g_strdup ((char *) lst->data);
 			}
 		} else {
@@ -428,12 +441,19 @@ gnome_kbd_indicator_kbd_cfg_callback (GnomeKbdIndicator * gki)
 					       &globals.kbd_cfg);
 
 	g_strfreev (globals.full_group_names);
-	g_strfreev (globals.short_group_names);
+	globals.full_group_names = NULL;
+
+	if (globals.short_group_names != NULL) {
+		g_strfreev (globals.short_group_names);
+		globals.short_group_names = NULL;
+	}
+
 	gnome_kbd_indicator_load_group_names ();
 
 	ForAllIndicators () {
 		gnome_kbd_indicator_reinit_ui (gki);
-	} NextIndicator ();
+	}
+	NextIndicator ();
 }
 
 /* Should be called once for all applets */
@@ -553,13 +573,15 @@ gnome_kbd_indicator_scroll (GtkWidget * gki, GdkEventScroll * event)
 static void
 gnome_kbd_indicator_init (GnomeKbdIndicator * gki)
 {
+	GtkWidget *def_drawing;
+	GtkNotebook *notebook;
+
 	if (!g_slist_length (globals.widget_instances))
 		gnome_kbd_indicator_global_init ();
 
 	gki->priv = g_new0 (GnomeKbdIndicatorPrivate, 1);
 
-	GtkWidget *def_drawing;
-	GtkNotebook *notebook = GTK_NOTEBOOK (gki);
+	notebook = GTK_NOTEBOOK (gki);
 
 	xkl_debug (100, "Initiating the widget startup process for %p\n",
 		   gki);
@@ -667,8 +689,6 @@ gnome_kbd_indicator_class_init (GnomeKbdIndicatorClass * klass)
 		      G_STRUCT_OFFSET (GnomeKbdIndicatorClass, reinit_ui),
 		      NULL, NULL, gnome_kbd_indicator_VOID__VOID,
 		      G_TYPE_NONE, 0);
-
-
 }
 
 static void
