@@ -19,6 +19,7 @@
 #include <string.h>
 #include <time.h>
 
+#include <glibtop.h>
 #include <gdk/gdkkeysyms.h>
 #include <gtk/gtk.h>
 #include <gdk-pixbuf/gdk-pixbuf.h>
@@ -62,7 +63,7 @@ about_cb (BonoboUIComponent *uic,
 	"authors",	authors,
 	"documenters",	documenters,
 	"translator-credits",	_("translator-credits"),
-	"logo-icon-name",	"gnome-monitor",
+	"logo-icon-name",	"utilities-system-monitor",
 	NULL);
 }
 
@@ -471,7 +472,7 @@ multiload_applet_new(PanelApplet *applet, const gchar *iid, gpointer data)
 	ma->prop_dialog = NULL;
         ma->last_clicked = 0;
 
-	gtk_window_set_default_icon_name ("gnome-monitor");
+	gtk_window_set_default_icon_name ("utilities-system-monitor");
 	panel_applet_set_background_widget (applet, GTK_WIDGET(applet));
 	
 	panel_applet_add_preferences (applet, "/schemas/apps/multiload/prefs", NULL);
@@ -533,6 +534,8 @@ multiload_factory (PanelApplet *applet,
 {
 	gboolean retval = FALSE;
 	
+	glibtop_init();
+
 	retval = multiload_applet_new(applet, iid, data);
 	
 	return retval;
